@@ -119,7 +119,10 @@ is inserted before the cursor, the short name is expanded to its address."
         (completion-ignore-case mew-complete-folder-ignore-case))
     (if (null word)
         (mew-complete-window-show (list "+"))
-      (mew-complete word (mew-local-folder-alist) "folder" nil))))
+      (if (and (mew-folder-absolutep word)
+	       (not (mew-draft-or-header-p)))
+	  (mew-complete word (mew-complete-directory-alist word) "directory" nil)
+	(mew-complete word (mew-local-folder-alist) "folder" nil)))))
 
 (defun mew-complete-imap-folder ()
   "IMAP folder complete function."
@@ -157,9 +160,7 @@ is inserted before the cursor, the short name is expanded to its address."
 	(mew-complete2 fld (mew-imap-folder-alist case) case))
        ((mew-folder-virtualp fld)
 	(mew-complete
-	 word
-	 (mew-buffer-list (concat "^" case ":\\*[$+%-]") t) ;; xxx
-	 "folder" nil))
+	 word (mew-buffer-list "^\\*" t 'mew-virtual-mode) "folder" nil))
        ((string= fld "")
 	(insert word)
 	(mew-complete-window-show
@@ -181,7 +182,10 @@ is inserted before the cursor, the short name is expanded to its address."
        ((mew-folder-imapp word)
 	(mew-complete word (mew-imap-folder-alist case) "mailbox" nil))
        ((mew-folder-virtualp word)
-	(mew-complete word (mew-buffer-list "^\\*[$+%-]" t) "folder" nil))
+	(mew-complete
+	 word (mew-buffer-list "^\\*" t 'mew-virtual-mode) "folder" nil))
+       ((mew-folder-absolutep word)
+	(mew-complete word (mew-complete-directory-alist word) "directory" nil))
        (t
 	(mew-complete
 	 word
@@ -379,6 +383,32 @@ the name exists."
       (setq alist mew-sort-key-alist))
     (mew-complete word alist "sort key" nil)))
 
+(defun mew-complete-directory-alist (dir)
+  "Return alist of directories for completion."
+  (let ((odir dir) odir1 dirs1 sub dirs2)
+    (setq dir (mew-file-chase-links (expand-file-name dir)))
+    (when (file-directory-p dir)
+      (setq odir1 (file-name-as-directory odir))
+      (setq dirs1 (mapcar
+		   (lambda (x)
+		     (when (file-directory-p (expand-file-name x dir))
+		       (cons (concat odir1 (file-name-as-directory x)) x)))
+		   (directory-files dir nil "[^.]" 'nosort))))
+    (setq sub (file-name-nondirectory dir))
+    (setq odir (file-name-directory odir))
+    (setq dir (file-name-directory dir))
+    (when (and dir odir sub (not (string= sub "")))
+      (setq odir (file-name-as-directory odir))
+      (setq dirs2 (mapcar
+		   (lambda (x)
+		     (when (file-directory-p (expand-file-name x dir))
+		       (cons (concat odir (file-name-as-directory x)) x)))
+		   (directory-files dir nil
+				    (concat "^" (regexp-quote sub))
+				    'nosort))))
+    (sort (delq nil (append dirs2 dirs1))
+	  (lambda (x y) (string< (car x) (car y))))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Hart function for completions
