@@ -26,7 +26,7 @@ Execute mew-dinfo-set before calling this."
 	(error
 	 (error "MIME decoding error: %s" (mew-xinfo-get-decode-err)))))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Header mode
 ;;;
@@ -87,56 +87,97 @@ Execute mew-dinfo-set before calling this."
 (defun mew-header-process-message (action)
   (if (not (file-readable-p (mew-tinfo-get-hdr-file)))
       (message "No corresponding message!")
-    (let* ((buf (current-buffer))
-	   (case (mew-tinfo-get-case))
-	   (server (mew-smtp-server case))
-	   (ssh-server (mew-smtp-ssh-server case))
-	   (pnm (mew-smtp-info-name case))
-	   sendit resentp fcc err)
-      (if (mew-smtp-get-lock pnm)
-	  (message "Another message is being sent. Try later")
-	(goto-char (point-min))
-	(setq resentp (mew-draft-resent-p (mew-header-end)))
-	(setq fcc (mew-encode-ask-fcc resentp))
-	(if (and (eq action 'send) mew-ask-send)
-	    (setq sendit (y-or-n-p "Really send this message? "))
-	  (setq sendit t))
-	(when sendit
-	  (mew-smtp-set-case pnm case)
-	  (mew-smtp-set-server pnm server)
-	  (mew-smtp-set-port pnm (mew-smtp-port case))
-	  (mew-smtp-set-ssh-server pnm ssh-server)
-	  (mew-smtp-set-queue pnm (mew-queue-folder case))
-	  (mew-smtp-set-fcc pnm fcc)
-	  (mew-current-get-window-config)
-	  (mew-redraw)
-	  (save-excursion
-	    (save-window-excursion
-	      (set-buffer buf)
-	      (mew-encode-make-backup)
-	      (mew-header-clear)
-	      ;; the end of the header
-	      (save-restriction
-		(narrow-to-region (point) (point))
-		(mew-frwlet
-		 mew-cs-text-for-read mew-cs-text-for-write
-		 (insert-file-contents (mew-tinfo-get-hdr-file)))
-		(goto-char (point-min))
-		(mew-header-goto-end)
-		(mew-header-set mew-header-separator)
-		(mew-header-delete-lines mew-field-delete-common)
-		(mew-header-delete-lines (mew-tinfo-get-field-del)))
-	      (if (mew-encode pnm case resentp nil nil 'header)
-		  (cond
-		   ((eq action 'queue)
-		    (mew-smtp-queue pnm "from Draft mode"))
-		   ((eq action 'send)
-		    (mew-smtp-send-message pnm)))
-		(setq err t))))
-	  (when err
-	    (mew-current-set-window-config)
-	    (switch-to-buffer buf)
-	    (delete-other-windows)))))))
+    (if (mew-header-existp mew-newsgroups:)
+	(mew-header-nntp-process-message action)
+      (mew-header-smtp-process-message action))))
+
+(defun mew-header-smtp-process-message (action)
+  (let* ((buf (current-buffer))
+	 (case (mew-tinfo-get-case))
+	 (pnm (mew-smtp-info-name case))
+	 sendit resentp fcc err)
+    (if (get-process pnm)
+	(message "Another message is being sent. Try later")
+      (goto-char (point-min))
+      (setq resentp (mew-draft-resent-p (mew-header-end)))
+      (setq fcc (mew-encode-ask-fcc resentp))
+      (if (and (eq action 'send) mew-ask-send)
+	  (setq sendit (y-or-n-p "Really send this message? "))
+	(setq sendit t))
+      (when sendit
+	(mew-current-get-window-config)
+	(mew-redraw)
+	(save-excursion
+	  (save-window-excursion
+	    (set-buffer buf)
+	    (mew-encode-make-backup)
+	    (mew-header-clear)
+	    ;; the end of the header
+	    (save-restriction
+	      (narrow-to-region (point) (point))
+	      (mew-frwlet
+	       mew-cs-text-for-read mew-cs-text-for-write
+	       (insert-file-contents (mew-tinfo-get-hdr-file)))
+	      (goto-char (point-min))
+	      (mew-header-goto-end)
+	      (mew-header-set mew-header-separator)
+	      (mew-header-delete-lines mew-field-delete-common)
+	      (mew-header-delete-lines (mew-tinfo-get-field-del)))
+	    (if (mew-smtp-encode pnm case resentp fcc nil nil 'header)
+		(cond
+		 ((eq action 'queue)
+		  (mew-smtp-queue case "from Draft mode"))
+		 ((eq action 'send)
+		  (mew-smtp-send-message case)))
+	      (setq err t))))
+	(when err
+	  (mew-current-set-window-config)
+	  (switch-to-buffer buf)
+	  (delete-other-windows))))))
+
+(defun mew-header-nntp-process-message (action)
+  (let* ((buf (current-buffer))
+	 (case (mew-tinfo-get-case))
+	 (pnm (mew-nntp2-info-name case))
+	 sendit resentp fcc err)
+    (if (get-process pnm)
+	(message "Another message is being posted. Try later")
+      (goto-char (point-min))
+      (setq resentp (mew-draft-resent-p (mew-header-end)))
+      (setq fcc (mew-encode-ask-fcc resentp))
+      (if (and (eq action 'send) mew-ask-send)
+	  (setq sendit (y-or-n-p "Really post this message? "))
+	(setq sendit t))
+      (when sendit
+	(mew-current-get-window-config)
+	(mew-redraw)
+	(save-excursion
+	  (save-window-excursion
+	    (set-buffer buf)
+	    (mew-encode-make-backup)
+	    (mew-header-clear)
+	    ;; the end of the header
+	    (save-restriction
+	      (narrow-to-region (point) (point))
+	      (mew-frwlet
+	       mew-cs-text-for-read mew-cs-text-for-write
+	       (insert-file-contents (mew-tinfo-get-hdr-file)))
+	      (goto-char (point-min))
+	      (mew-header-goto-end)
+	      (mew-header-set mew-header-separator)
+	      (mew-header-delete-lines mew-field-delete-common)
+	      (mew-header-delete-lines (mew-tinfo-get-field-del)))
+	    (if (mew-nntp2-encode pnm case fcc nil nil 'header)
+		(cond
+		 ((eq action 'queue)
+		  (mew-nntp2-queue case "from Draft mode"))
+		 ((eq action 'send)
+		  (mew-nntp2-send-message case)))
+	      (setq err t))))
+	(when err
+	  (mew-current-set-window-config)
+	  (switch-to-buffer buf)
+	  (delete-other-windows))))))
 
 (defun mew-header-make-message ()
   (interactive)
@@ -146,7 +187,7 @@ Execute mew-dinfo-set before calling this."
   (interactive)
   (mew-header-process-message 'send))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Saving
 ;;;
@@ -271,7 +312,7 @@ a text object to be saved can be specified."
 	      (write-region (point-min) (point-max) file append-p))))))
      (mew-remove-buffer buf))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Local cs
 ;;;
@@ -321,7 +362,7 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	 ;; Now, let's analyze the message in the burst buffer.
 	 ;; This is lengthy, though, avoidable.
 	 (setq limit (length nums))
-	 (if (or PLUS1P bodyp);; VERY important for PGP/MIME
+	 (if (or PLUS1P bodyp) ;; VERY important for PGP/MIME
 	     (setq limit (1+ limit)))
 	 ;;
 	 (set-buffer buf)
@@ -373,80 +414,94 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	 (select-window win))
        (mew-remove-buffer buf)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Burst
 ;;;
 
-(defun mew-summary-burst-body (fld msg folder)
+(defun mew-summary-burst-body (fld msg folder &optional num)
   (save-excursion
     (let ((buf (generate-new-buffer mew-buffer-prefix))
-	  ret errmsg entry multi mstr m n len)
+	  ret errmsg mstr m)
       (set-buffer buf)
       (mew-erase-buffer)
       (mew-insert-message fld msg mew-cs-text-for-read nil)
       (mew-dinfo-set 1 nil nil nil) ;; xxx
       (mew-decode-for-edit)
-      (setq multi (mew-syntax-get-part mew-decode-syntax))
+      (mew-local-folder-check folder)
       (cond
-       ((not (mew-syntax-multipart-p multi))
+       ((not (mew-syntax-multipart-p (mew-syntax-get-part mew-decode-syntax)))
 	(message "Cannot burst"))
-       ((not (mew-folder-check folder))
-	(setq errmsg (format "%s is wrong. Nothing was processed" folder)))
        ((not (setq mstr (mew-folder-new-message folder 'num-only)))
 	(setq errmsg (format "Error in %s. Nothing was processed" folder)))
        (t
-	(setq m (string-to-int mstr))
-	(setq len (- (length multi) mew-syntax-magic))
-	(setq n 1)
-	(while (<= n len)
-	  (setq entry (mew-syntax-get-entry mew-decode-syntax (list n)))
-	  (if (not
-	       (string=
-		(mew-syntax-get-value (mew-syntax-get-ct entry) 'cap)
-		mew-ct-msg))
-	      () ;; return value
-	    (mew-frwlet
-	     mew-cs-dummy mew-cs-text-for-write
-	     (write-region
-	      (mew-syntax-get-begin entry)
-	      ;; This is RFC 822 message.
-	      ;; So, body is a single text/plain.
-	      (mew-syntax-get-end (mew-syntax-get-part entry))
-	      (mew-expand-folder folder (int-to-string m))
-	      nil 'no-msg))
-	    (setq m (1+ m)))
-	  (setq n (1+ n)))
-	(mew-touch-folder folder)
-	(setq ret (list mstr (int-to-string (1- m))))))
+	(setq m (mew-summary-burst-part (mew-syntax-get-part mew-decode-syntax)
+					folder (string-to-int mstr) num))
+	(if (= m (string-to-int mstr))
+	    (message "Nothing was processed")
+	  (mew-touch-folder folder)
+	  (setq ret (list mstr (int-to-string (1- m)))))))
       (mew-remove-buffer buf)
       (if errmsg (error errmsg))
       ret)))
 
+(defun mew-summary-burst-part (part folder newmsg &optional num)
+  (let (n len nums entry)
+    (setq n 1)
+    (cond
+     (num
+      (setq nums (mew-syntax-number-to-nums num))
+      (setq len 1))
+     (t
+      (setq nums (list n))
+      (setq len (- (length part) mew-syntax-magic))))
+    (while (<= n len)
+      (setq entry (mew-syntax-get-entry part nums))
+      (cond
+       ((mew-syntax-multipart-p entry)
+	(setq newmsg (mew-summary-burst-part entry folder newmsg)))
+       ((string= (mew-syntax-get-value (mew-syntax-get-ct entry) 'cap)
+		 mew-ct-msg)
+	(mew-frwlet
+	 mew-cs-dummy mew-cs-text-for-write
+	 (write-region
+	  (mew-syntax-get-begin entry)
+	  ;; This is RFC 822 message.
+	  ;; So, body is a single text/plain.
+	  (mew-syntax-get-end (mew-syntax-get-part entry))
+	  (mew-expand-folder folder (int-to-string newmsg))
+	  nil 'no-msg))
+	(setq newmsg (1+ newmsg))))
+      (setq n (1+ n))
+      (setq nums (list n)))
+    newmsg))
+
 (defvar mew-burst-last-folder nil)
 
 (defun mew-input-burst-folder ()
   (let (default)
      (if (and mew-use-burst-folder-history mew-burst-last-folder)
 	 (setq default mew-burst-last-folder)
-       (setq default (mew-inbox-folder)))
-     (setq mew-burst-last-folder (mew-input-folder default))
+       (setq default (mew-inbox-folder))) ;; local folder
+     (setq mew-burst-last-folder (mew-input-folder default 'local-only))
      mew-burst-last-folder))
 
-(defun mew-summary-burst ()
-  "De-capsulate messages embedded in this message."
-  (interactive)
+(defun mew-summary-burst (&optional arg)
+  "De-capsulate messages embedded in this message.
+If called with '\\[universal-argument]', the current part is de-capsulated."
+  (interactive "P")
   (mew-summary-msg-or-part
    (let ((fld (mew-summary-folder-name))
 	 (msg (mew-summary-message-number2))
 	 (folder (mew-input-burst-folder))
+	 (num (if arg (mew-syntax-number)))
 	 ret)
      (message "Bursting...")
-     (setq ret (mew-summary-burst-body fld msg folder))
+     (setq ret (mew-summary-burst-body fld msg folder num))
      (when ret
        (message "Bursting...done")
        (if (y-or-n-p (format "Go to %s? " folder))
-	   (mew-summary-goto-folder t folder))
+	   (mew-summary-visit-folder folder 'goend))
        (message "Messages from %s to %s were extracted in %s"
 		(nth 0 ret) (nth 1 ret) folder)))))
 
@@ -462,9 +517,9 @@ If executed with '\\[universal-argument]', coding-system is asked."
        (setq targets (cdr targets)))
      (message "Bursting...done")
      (if (y-or-n-p (format "Go to %s? " folder))
-	 (mew-summary-goto-folder t folder)))))
+	 (mew-summary-visit-folder folder 'goend)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Old burst
 ;;;
@@ -513,9 +568,9 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	 (setq done t)))
      (mew-remove-buffer buf)
      (if (and done (y-or-n-p (format "Go to %s? " folder)))
-	 (mew-summary-goto-folder t folder)))))
+	 (mew-summary-visit-folder folder 'goend)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Re-editing
 ;;;
@@ -525,11 +580,9 @@ If executed with '\\[universal-argument]', coding-system is asked."
 typically included in a MIME-encapsulated error message.
 
 1. In +draft, the message is just edited.
-2. In +queue, the message is moved to +draft and is edited.
+2. In +queue or +postq, the message is moved to +draft and is edited.
 3. Otherwise, the message is copied to +draft and is edited. 
 
-For +draft and +queue, the sending case revives.
-
 For the other folders, if mew-case-guess-when-prepared is 't', each
 fields of the original header is replaced according to a guessed
 sending case.  If called with '\\[universal-argument]', the original
@@ -544,7 +597,7 @@ See also mew-summary-edit-again."
 	 draftname)
      (cond
       ((string= fld mew-draft-folder)
-       (setq draftname (mew-draft-buffer-name (mew-expand-folder fld msg)))
+       (setq draftname (mew-path-to-folder (mew-expand-folder fld msg)))
        (if (get-buffer draftname)
 	   (progn
 	     (mew-current-set-window-config) ;; xxx necessary?
@@ -552,10 +605,7 @@ See also mew-summary-edit-again."
 	     (switch-to-buffer draftname))
 	 (mew-summary-reedit-for-draft fld msg)
 	 (run-hooks 'mew-draft-mode-reedit-draft-hook)))
-      ((and (mew-folder-queuep fld) (null part))
-       (mew-decode-syntax-delete)
-       (mew-mark-kill-line)
-       (set-buffer-modified-p nil)
+      ((and (or (mew-folder-queuep fld) (mew-folder-postqp fld)) (null part))
        (mew-summary-reedit-for-queue fld msg)
        (run-hooks 'mew-draft-mode-reedit-queue-hook))
       (t
@@ -572,7 +622,7 @@ See also mew-summary-edit-again."
 	 (mew-summary-reedit-for-message fld msg nil keep-hdr nil)
 	 (run-hooks 'mew-draft-mode-reedit-hook)))))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Header
 ;;;
@@ -607,7 +657,7 @@ See also mew-summary-edit-again."
      (mew-draft-replace-fields nil))
    (mew-summary-edit-header-common)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Body
 ;;;
@@ -639,6 +689,12 @@ Note that the message is not a valid MIME message."
 (defun mew-summary-reedit-for-queue (fld msg)
   "Edit a message in a folder other than the draft folder.
 The message is assumed to be a valid MIME message."
+  ;; Message mode will be invalid so hide it.
+  (mew-decode-syntax-delete)
+  (mew-mark-kill-line)
+  (set-buffer-modified-p nil)
+  ;; Need to delete Message window because the target message will be
+  ;; modified and its content wiil be changed.
   (mew-current-set-window-config)
   (mew-window-configure 'draft)
   ;; main part
@@ -647,15 +703,17 @@ The message is assumed to be a valid MIME message."
    (let* ((file (mew-expand-folder fld msg))
 	  (work (concat file mew-queue-work-suffix))
 	  (info (concat file mew-queue-info-suffix))
-	  inf hdr case)
+	  inf hdr)
      (when (file-readable-p file)
        (rename-file file work 'override)
        (setq inf (mew-lisp-load info))
-       (setq hdr (mew-smtp-get-raw-header inf)) ;; fcc/dcc/bcc included
-       (setq case (mew-smtp-get-case inf))
-       (mew-queue-backup file)
-       (mew-tinfo-set-case case)
-       (mew-summary-edit-header-for-queue hdr)))
+       (cond
+	((mew-folder-queuep fld)
+	 (setq hdr (mew-smtp-get-raw-header inf)))
+	((mew-folder-postqp fld)
+	 (setq hdr (mew-nntp2-get-raw-header inf))))
+       (mew-queue-backup file mew-queue-info-suffix)
+       (and hdr (mew-summary-edit-header-for-queue hdr))))
    (mew-draft-mode)
    (mew-draft-rehighlight-body)
    (when mew-encode-syntax
@@ -681,7 +739,7 @@ The message is assumed to be a valid MIME message."
        (mew-draft-prepare-attachments t)))
    (mew-draft-mode-name)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Edit again
 ;;;
@@ -723,10 +781,10 @@ mew-summary-reedit."
 	 ;; A new message is stored in the temporary directory
 	 (mew-summary-reedit-for-message nfld nmsg nil nil nil)
 	 (run-hooks 'mew-draft-mode-edit-again-hook)
-	 (if (file-exists-p nfile) (delete-file nfile))))
+	 (mew-delete-file nfile)))
      (mew-remove-buffer buf))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; SUb functions
 ;;;
