@@ -209,7 +209,10 @@ on all frames."
   (defsubst mew-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p (file-chase-links filename))
 	(error "Cannot make a link to directory")
-      (add-name-to-file filename newname OK-IF-ALREADY-EXISTS))))
+      (condition-case nil
+	  (add-name-to-file filename newname OK-IF-ALREADY-EXISTS)
+	(file-error
+	 (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate))))))
  (t
   (defsubst mew-symbolic-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p filename)
