@@ -469,6 +469,11 @@ also ignored."
 
 ;;
 
+(defsubst mew-folder-absolutep (folder)
+  (or (string-match mew-regex-file-absolute folder)
+      (and (featurep 'mew-win32)
+	   (string-match mew-regex-drive-letter folder))))
+
 (defsubst mew-folder-localp (folder)
   (string-match "^\\+" folder))
 
@@ -485,10 +490,12 @@ also ignored."
   (string-match "^%" folder))
 
 (defsubst mew-folder-virtualp (folder)
-  (let ((case-folder (mew-folder-case folder)))
-    (if case-folder
-	(string-match "^\\*" (cdr case-folder))
-      (string-match "^\\*" folder))))
+  (string-match "^\\*" folder))
+
+(defsubst mew-virtual-thread-p (vfolder)
+  (save-excursion  
+    (set-buffer vfolder)
+    (mew-thread-p)))
 
 ;;
 
@@ -504,18 +511,13 @@ also ignored."
 ;;
 
 (defsubst mew-folder-to-virtual (folder)
-  (let ((case-folder (mew-folder-case folder)))
-    (if case-folder
-	(mew-folder-case-folder (car case-folder)
-				(concat mew-folder-virtual (cdr case-folder)))
-      (concat mew-folder-virtual folder))))
+  (concat mew-folder-virtual folder mew-folder-virtual))
 
-(defsubst mew-virtual-to-folder (folder)
-  (let ((case-folder (mew-folder-case folder)))
-    (if case-folder
-	(mew-folder-case-folder (car case-folder)
-				(mew-folder-string (cdr case-folder)))
-      (mew-folder-string folder))))
+(defsubst mew-folder-to-thread (folder)
+  (concat mew-folder-virtual folder))
+
+(defsubst mew-thread-to-folder (folder)
+  (mew-folder-string folder))
 
 ;;
 
@@ -567,6 +569,8 @@ also ignored."
       (setq folder (cdr case-folder)))
     (cond
      ((mew-folder-localp folder) folder)
+     ((mew-folder-absolutep folder) folder)
+     ((mew-folder-virtualp folder) folder)
      (case
       (if (string-equal case mew-case-default)
 	  folder
@@ -984,13 +988,18 @@ Does not examine containing directories for links."
 (defsubst mew-insert-buffer-substring (buf beg end)
   (insert (save-excursion (set-buffer buf) (mew-buffer-substring beg end))))
 
-(defun mew-buffer-list (regex &optional listp)
+(defun mew-buffer-list (regex &optional listp mode)
   (let ((bufs (mapcar 'buffer-name (buffer-list)))
 	buf ret)
     (while bufs
       (setq buf (car bufs))
       (setq bufs (cdr bufs))
-      (when (string-match regex buf)
+      (when (and (string-match regex buf)
+		 (or (not mode)
+		     (and mode (get-buffer buf)
+			  (save-excursion
+			    (set-buffer buf)
+			    (eq major-mode mode)))))
 	(if listp
 	    (setq ret (cons (list buf) ret))
 	  (setq ret (cons buf ret)))))
