@@ -140,6 +140,10 @@
   (define-key mew-summary-mode-map "tu"   'mew-thread-unmark)
   (define-key mew-summary-mode-map "z"    (make-sparse-keymap))
   (define-key mew-summary-mode-map "z8"   'mew-summary-toggle-8bit)
+  (define-key mew-summary-mode-map "zc"   'mew-summary-cache-clean-up)
+  (define-key mew-summary-mode-map "zd"   'mew-summary-toggle-debug)
+  (define-key mew-summary-mode-map "zp"   'mew-summary-toggle-policy)
+  (define-key mew-summary-mode-map "zw"   'mew-summary-toggle-warning)
   (define-key mew-summary-mode-map "l"	  (make-sparse-keymap))
   (define-key mew-summary-mode-map "lc"   'mew-summary-local-copy)
   ;;
