@@ -329,8 +329,7 @@ This function returns a folder."
     (cond
      ((null default)
       (setq file mew-home))
-     ((or (string-match mew-regex-file-absolute default)
-	  (string-match mew-regex-drive-letter default))
+     ((mew-folder-absolutep default)
       (setq file default))
      (t
       (setq file (concat mew-home default))))
