@@ -460,21 +460,21 @@ from the mailbox. When executed with '\\[universal-argument]',
 	    (setq siz (mew-summary-message-size))
 	    (setq rtr (list uid siz del (list bnm msg)))
 	    (setq rtrs (list rtr)))
-	  (if rtrs
+	  (if (not rtrs)
+	      (message "No message to be retrieved")
+	    (cond
+	     ((mew-folder-localp folder)
 	      (cond
-	       ((mew-folder-localp folder)
-		(cond
-		 ((eq mailbox 'pop)
-		  (mew-pop-retrieve case 'get bnm rtrs))
-		 ((eq mailbox 'imap)
-		  (mew-imap-retrieve case 'get bnm rtrs))))
-	       ((mew-folder-popp folder)
+	       ((eq mailbox 'pop)
 		(mew-pop-retrieve case 'get bnm rtrs))
-	       ((mew-folder-imapp folder)
-		(mew-imap-retrieve case 'get bnm rtrs))
-	       ((mew-folder-nntpp folder)
-		(mew-nntp-retrieve case 'get bnm rtrs)))
-	    (message "No message to be retrieved"))))))))
+	       ((eq mailbox 'imap)
+		(mew-imap-retrieve case 'get bnm rtrs))))
+	     ((mew-folder-popp folder)
+	      (mew-pop-retrieve case 'get bnm rtrs))
+	     ((mew-folder-imapp folder)
+	      (mew-imap-retrieve case 'get bnm rtrs))
+	     ((mew-folder-nntpp folder)
+	      (mew-nntp-retrieve case 'get bnm rtrs))))))))))
 
 (defun mew-summary-mark-retrieve-message (&optional rev-del)
   "Retrieve the rest of truncated('T') messages marked with '*'.
@@ -506,21 +506,23 @@ from the mailbox. When executed with '\\[universal-argument]',
 	   (setq rtr (list uid siz del (list bnm msg)))
 	   (setq rtrs (cons rtr rtrs)))
 	 (forward-line)))
-     (if rtrs
+     (if (not rtrs)
+	 (message "No message to be retrieved")
+       (setq rtrs (nreverse rtrs))
+       (cond
+	((mew-folder-localp folder)
 	 (cond
-	  ((mew-folder-localp folder)
-	   (cond
-	    ((eq mailbox 'pop)
-	     (mew-pop-retrieve case 'get bnm rtrs))
-	    ((eq mailbox 'imap)
-	     (mew-imap-retrieve case 'get bnm rtrs))))
-	  ((mew-folder-popp folder)
+	  ((eq mailbox 'pop)
 	   (mew-pop-retrieve case 'get bnm rtrs))
-	  ((mew-folder-imapp folder)
-	   (mew-imap-retrieve case 'get bnm rtrs))
-	  ((mew-folder-nntpp folder)
-	   (mew-nntp-retrieve case 'get bnm rtrs)))
-       (message "No message to be retrieved")))))
+	  ((eq mailbox 'imap)
+	   (mew-imap-retrieve case 'get bnm rtrs))))
+	((mew-folder-popp folder)
+	 (mew-pop-retrieve case 'get bnm rtrs))
+	((mew-folder-imapp folder)
+	 (mew-imap-retrieve case 'get bnm rtrs))
+	((mew-folder-nntpp folder)
+	 (mew-nntp-retrieve case 'get bnm rtrs)))))))
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
