@@ -95,10 +95,13 @@ effect to this function."
   (let ((s (MEW-DATE)))
     (if (or (string= s "")
 	    (not (string-match mew-time-rfc-regex s)))
-	"00:00"
-      (format "%02d:%02d"
-	      (or (mew-time-rfc-hour) 0)
-	      (or (mew-time-rfc-min)  0)))))
+	(setq s (mew-time-ctz-to-rfc
+		 (mew-file-get-time (mew-expand-folder (MEW-FLD) (MEW-NUM))))))
+    (if (string-match mew-time-rfc-regex s)
+	(format "%02d:%02d"
+		(or (mew-time-rfc-hour) 0)
+		(or (mew-time-rfc-min)  0))
+      "00:00")))
 
 (defun mew-scan-form-date ()
   "A function to return a date, MM/DD."
