@@ -78,7 +78,7 @@ Summary mode."
 	(select-frame (make-frame))))
     (mew-summary-visit-folder folder goend)))
 
-(defun mew-summary-visit-folder (&optional folder goend no-ls)
+(defun mew-summary-visit-folder (folder &optional goend no-ls)
   (let ((dir (mew-expand-folder folder))
 	new-folder scanp)
     (cond
@@ -94,14 +94,14 @@ Summary mode."
       (if (null dir)
 	  (message "Folder is wrong")
 	(cond
-	 ((mew-folder-localp folder)
-	  (if (file-directory-p dir)
-	      (setq scanp t)
-	    (message "No such folder %s" folder)))
-	 (t
+	 ((mew-folder-remotep (mew-folder-folder folder))
 	  (unless (file-directory-p dir)
 	    (mew-make-directory dir))
-	  (setq scanp t)))
+	  (setq scanp t))
+	 (t ;; +, ~, /, drive letter
+	  (if (file-directory-p dir)
+	      (setq scanp t)
+	    (message "No such folder %s" folder))))
 	(when scanp
 	  (if no-ls
 	      (progn
@@ -533,7 +533,7 @@ Use this command to solve this problem."
   (unwind-protect
       (let ((process mew-summary-buffer-process)
 	    pnm)
-	(if (null (processp process))
+	(if (not (processp process))
 	    (or no-msg (message "No process to kill. This buffer is unlocked anyway"))
 	  (cond
 	   ((eq process t)
@@ -543,7 +543,6 @@ Use this command to solve this problem."
 	    ;; Network process
 	    (setq pnm (process-name process))
 	    (mew-info-clean-up pnm)
-	    ;; xxx SSH process?
 	    (delete-process process)
 	    (mew-summary-visible-buffer (current-buffer))
 	    (when (mew-sinfo-get-refile-back)
@@ -557,46 +556,6 @@ Use this command to solve this problem."
 	  (or no-msg (message "The process was killed"))))
     (mew-summary-unlock)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Summary only vs Summary/Message
-;;;
-
-(defun mew-summary-toggle-disp-msg (&optional arg)
-  "Toggle 'Summary mode only' and 'Summary & Message mode'. If 
-you choose 'Summary mode only', you can quickly put the delete
-	marks since the next message is not displayed."
-  (interactive)
-  (cond 
-   ((eq arg 'on)
-    (mew-sinfo-set-disp-msg t))
-   ((eq arg 'off)
-    (mew-sinfo-set-disp-msg nil)
-    (mew-summary-reset-mode-line))
-   (t
-    (mew-sinfo-set-disp-msg (not (mew-sinfo-get-disp-msg)))
-    (if (mew-sinfo-get-disp-msg)
-	(mew-summary-display 'redisplay)
-      (mew-summary-goto-message)
-      (mew-decode-syntax-delete)
-      (mew-window-configure 'summary)
-      (mew-current-set nil nil nil)
-      (mew-summary-cook-window)
-      (mew-summary-reset-mode-line))))
-  (run-hooks 'mew-summary-toggle-disp-msg-hook))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; 8bit clean
-;;;
-
-(defun mew-summary-toggle-8bit ()
-  (interactive)
-  (setq mew-use-8bit (not mew-use-8bit))
-  (if mew-use-8bit
-      (message "mew-use-8bit has been set to 't'")
-    (message "mew-use-8bit has been set to 'nil'")))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; De-composing with the old style
@@ -707,8 +666,8 @@ message."   (interactive)
 	  (write-region (point-min) (point-max) tfile nil 'no-msg))
 	 (mew-erase-buffer)
 	 (call-process mew-prog-mewls nil t nil
-		       "-b" mew-mail-path
-		       "-i" tfile "-d" "content-type" "-l" "0")
+		       "-b" mew-mail-path "-l" "0"
+		       "-i" tfile "-d" "content-type")
 	 (mew-delete-file tfile)
 	 (goto-char (point-min))
 	 (while (not (eobp))
@@ -859,6 +818,108 @@ to clean up."
        (mew-remove-buffer buf)
        (message "Copied to %s/%s" dstfld dstmsg)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Toggle
+;;;
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Summary only vs Summary/Message
+;;;
+
+(defun mew-summary-toggle-disp-msg (&optional arg)
+  "Toggle 'Summary mode only' and 'Summary & Message mode'. If 
+you choose 'Summary mode only', you can quickly put the delete
+	marks since the next message is not displayed."
+  (interactive)
+  (cond 
+   ((eq arg 'on)
+    (mew-sinfo-set-disp-msg t))
+   ((eq arg 'off)
+    (mew-sinfo-set-disp-msg nil)
+    (mew-summary-reset-mode-line))
+   (t
+    (mew-sinfo-set-disp-msg (not (mew-sinfo-get-disp-msg)))
+    (if (mew-sinfo-get-disp-msg)
+	(mew-summary-display 'redisplay)
+      (mew-summary-goto-message)
+      (mew-decode-syntax-delete)
+      (mew-window-configure 'summary)
+      (mew-current-set nil nil nil)
+      (mew-summary-cook-window)
+      (mew-summary-reset-mode-line))))
+  (run-hooks 'mew-summary-toggle-disp-msg-hook))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; 8bit clean
+;;;
+
+(defun mew-summary-toggle-8bit ()
+  (interactive)
+  (setq mew-use-8bit (not mew-use-8bit))
+  (if mew-use-8bit
+      (message "mew-use-8bit has been set to 't'")
+    (message "mew-use-8bit has been set to 'nil'")))
+
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Mew cache clean up
+;;;
+
+(defun mew-summary-cache-clean-up ()
+  "Clean-up mew cache."
+  (interactive)
+  (mew-cache-clean-up)
+  (message "Mew cache clean up...done"))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Toggle warning
+;;;
+
+(defun mew-summary-toggle-warning ()
+  "Toggle waring level."
+  (interactive)
+  (if (= mew-warning-field-level 2)
+      (setq mew-warning-field-level 1)
+    (setq mew-warning-field-level 2))
+  (mew-cache-clean-up)
+  (mew-summary-analyze-again)
+  (message "Mew warning level %d" mew-warning-field-level))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Toggle decode policy
+;;;
+
+(defun mew-summary-toggle-policy (&optional arg)
+  "Toggle decode policy."
+  (interactive "P")
+  (if arg
+      (setq mew-decode-broken nil
+	    mew-use-name-parameter nil)
+    (setq mew-decode-broken (not mew-decode-broken))
+    (setq mew-use-name-parameter (not mew-use-name-parameter)))
+  (mew-cache-clean-up)
+  (mew-summary-analyze-again)
+  (message "Mew \"%s\" mode" (if mew-decode-broken "TOLERANT" "STRICT")))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Toggle debug
+;;;
+
+(defun mew-summary-toggle-debug ()
+  "Toggle 'mew-debug'."
+  (interactive)
+  (setq mew-debug (not mew-debug))
+  (if mew-debug
+      (message "'mew-debug' is now 't'")
+    (message "'mew-debug' is now 'nil'")))
+
 (provide 'mew-summary4)
 
 ;;; Copyright Notice:
